@@ -120,6 +120,21 @@ cloudfront.Distribution(self, "myDist",
     )
 )
 ```
+
+## From an API Gateway REST API
+
+Origins can be created from an API Gateway REST API. It is recommended to use a
+[regional API](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-api-endpoint-types.html) in this case.
+
+```python
+# api: apigateway.RestApi
+
+cloudfront.Distribution(self, "Distribution",
+    default_behavior=cloudfront.BehaviorOptions(origin=origins.RestApiOrigin(api))
+)
+```
+
+The origin path will automatically be set as the stage name.
 '''
 import abc
 import builtins
@@ -133,6 +148,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk.aws_apigateway
 import aws_cdk.aws_cloudfront
 import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_s3
@@ -173,10 +189,10 @@ class HttpOrigin(
         origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
         protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
         read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -187,10 +203,10 @@ class HttpOrigin(
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         props = HttpOriginProps(
@@ -200,10 +216,10 @@ class HttpOrigin(
             origin_ssl_protocols=origin_ssl_protocols,
             protocol_policy=protocol_policy,
             read_timeout=read_timeout,
+            origin_path=origin_path,
             connection_attempts=connection_attempts,
             connection_timeout=connection_timeout,
             custom_headers=custom_headers,
-            origin_path=origin_path,
             origin_shield_region=origin_shield_region,
         )
 
@@ -223,8 +239,8 @@ class HttpOrigin(
         "connection_attempts": "connectionAttempts",
         "connection_timeout": "connectionTimeout",
         "custom_headers": "customHeaders",
-        "origin_path": "originPath",
         "origin_shield_region": "originShieldRegion",
+        "origin_path": "originPath",
         "http_port": "httpPort",
         "https_port": "httpsPort",
         "keepalive_timeout": "keepaliveTimeout",
@@ -240,8 +256,8 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         http_port: typing.Optional[jsii.Number] = None,
         https_port: typing.Optional[jsii.Number] = None,
         keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
@@ -254,8 +270,8 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
@@ -296,10 +312,10 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
             self._values["connection_timeout"] = connection_timeout
         if custom_headers is not None:
             self._values["custom_headers"] = custom_headers
-        if origin_path is not None:
-            self._values["origin_path"] = origin_path
         if origin_shield_region is not None:
             self._values["origin_shield_region"] = origin_shield_region
+        if origin_path is not None:
+            self._values["origin_path"] = origin_path
         if http_port is not None:
             self._values["http_port"] = http_port
         if https_port is not None:
@@ -346,17 +362,6 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         result = self._values.get("custom_headers")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
-    @builtins.property
-    def origin_path(self) -> typing.Optional[builtins.str]:
-        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
-
-        Must begin, but not end, with '/' (e.g., '/production/images').
-
-        :default: '/'
-        '''
-        result = self._values.get("origin_path")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def origin_shield_region(self) -> typing.Optional[builtins.str]:
         '''When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
@@ -368,6 +373,17 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         result = self._values.get("origin_shield_region")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def origin_path(self) -> typing.Optional[builtins.str]:
+        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+
+        Must begin, but not end, with '/' (e.g., '/production/images').
+
+        :default: '/'
+        '''
+        result = self._values.get("origin_path")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
         '''The HTTP port that CloudFront uses to connect to the origin.
@@ -485,10 +501,10 @@ class LoadBalancerV2Origin(
         origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
         protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
         read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -499,10 +515,10 @@ class LoadBalancerV2Origin(
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
         :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         props = LoadBalancerV2OriginProps(
@@ -512,10 +528,10 @@ class LoadBalancerV2Origin(
             origin_ssl_protocols=origin_ssl_protocols,
             protocol_policy=protocol_policy,
             read_timeout=read_timeout,
+            origin_path=origin_path,
             connection_attempts=connection_attempts,
             connection_timeout=connection_timeout,
             custom_headers=custom_headers,
-            origin_path=origin_path,
             origin_shield_region=origin_shield_region,
         )
 
@@ -529,8 +545,8 @@ class LoadBalancerV2Origin(
         "connection_attempts": "connectionAttempts",
         "connection_timeout": "connectionTimeout",
         "custom_headers": "customHeaders",
-        "origin_path": "originPath",
         "origin_shield_region": "originShieldRegion",
+        "origin_path": "originPath",
         "http_port": "httpPort",
         "https_port": "httpsPort",
         "keepalive_timeout": "keepaliveTimeout",
@@ -546,8 +562,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         http_port: typing.Optional[jsii.Number] = None,
         https_port: typing.Optional[jsii.Number] = None,
         keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
@@ -560,8 +576,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param http_port: The HTTP port that CloudFront uses to connect to the origin. Default: 80
         :param https_port: The HTTPS port that CloudFront uses to connect to the origin. Default: 443
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
@@ -592,10 +608,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
             self._values["connection_timeout"] = connection_timeout
         if custom_headers is not None:
             self._values["custom_headers"] = custom_headers
-        if origin_path is not None:
-            self._values["origin_path"] = origin_path
         if origin_shield_region is not None:
             self._values["origin_shield_region"] = origin_shield_region
+        if origin_path is not None:
+            self._values["origin_path"] = origin_path
         if http_port is not None:
             self._values["http_port"] = http_port
         if https_port is not None:
@@ -642,17 +658,6 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         result = self._values.get("custom_headers")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
-    @builtins.property
-    def origin_path(self) -> typing.Optional[builtins.str]:
-        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
-
-        Must begin, but not end, with '/' (e.g., '/production/images').
-
-        :default: '/'
-        '''
-        result = self._values.get("origin_path")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def origin_shield_region(self) -> typing.Optional[builtins.str]:
         '''When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
@@ -664,6 +669,17 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         result = self._values.get("origin_shield_region")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def origin_path(self) -> typing.Optional[builtins.str]:
+        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+
+        Must begin, but not end, with '/' (e.g., '/production/images').
+
+        :default: '/'
+        '''
+        result = self._values.get("origin_path")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
         '''The HTTP port that CloudFront uses to connect to the origin.
@@ -889,6 +905,212 @@ class OriginGroupProps:
         )
 
 
+class RestApiOrigin(
+    aws_cdk.aws_cloudfront.OriginBase,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-cloudfront-origins.RestApiOrigin",
+):
+    '''An Origin for an API Gateway REST API.
+
+    :exampleMetadata: infused
+
+    Example::
+
+        # api: apigateway.RestApi
+        
+        cloudfront.Distribution(self, "Distribution",
+            default_behavior=cloudfront.BehaviorOptions(origin=origins.RestApiOrigin(api))
+        )
+    '''
+
+    def __init__(
+        self,
+        rest_api: aws_cdk.aws_apigateway.RestApi,
+        *,
+        keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        connection_attempts: typing.Optional[jsii.Number] = None,
+        connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_shield_region: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param rest_api: -
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
+        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
+        '''
+        props = RestApiOriginProps(
+            keepalive_timeout=keepalive_timeout,
+            read_timeout=read_timeout,
+            connection_attempts=connection_attempts,
+            connection_timeout=connection_timeout,
+            custom_headers=custom_headers,
+            origin_shield_region=origin_shield_region,
+        )
+
+        jsii.create(self.__class__, self, [rest_api, props])
+
+    @jsii.member(jsii_name="renderCustomOriginConfig")
+    def _render_custom_origin_config(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_cloudfront.CfnDistribution.CustomOriginConfigProperty]:
+        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.CfnDistribution.CustomOriginConfigProperty], jsii.invoke(self, "renderCustomOriginConfig", []))
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-cloudfront-origins.RestApiOriginProps",
+    jsii_struct_bases=[aws_cdk.aws_cloudfront.OriginOptions],
+    name_mapping={
+        "connection_attempts": "connectionAttempts",
+        "connection_timeout": "connectionTimeout",
+        "custom_headers": "customHeaders",
+        "origin_shield_region": "originShieldRegion",
+        "keepalive_timeout": "keepaliveTimeout",
+        "read_timeout": "readTimeout",
+    },
+)
+class RestApiOriginProps(aws_cdk.aws_cloudfront.OriginOptions):
+    def __init__(
+        self,
+        *,
+        connection_attempts: typing.Optional[jsii.Number] = None,
+        connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_shield_region: typing.Optional[builtins.str] = None,
+        keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+    ) -> None:
+        '''Properties for an Origin for an API Gateway REST API.
+
+        :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
+        :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
+        :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
+        :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
+        :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(5)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_cloudfront_origins as cloudfront_origins
+            import aws_cdk.core as cdk
+            
+            rest_api_origin_props = cloudfront_origins.RestApiOriginProps(
+                connection_attempts=123,
+                connection_timeout=cdk.Duration.minutes(30),
+                custom_headers={
+                    "custom_headers_key": "customHeaders"
+                },
+                keepalive_timeout=cdk.Duration.minutes(30),
+                origin_shield_region="originShieldRegion",
+                read_timeout=cdk.Duration.minutes(30)
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if connection_attempts is not None:
+            self._values["connection_attempts"] = connection_attempts
+        if connection_timeout is not None:
+            self._values["connection_timeout"] = connection_timeout
+        if custom_headers is not None:
+            self._values["custom_headers"] = custom_headers
+        if origin_shield_region is not None:
+            self._values["origin_shield_region"] = origin_shield_region
+        if keepalive_timeout is not None:
+            self._values["keepalive_timeout"] = keepalive_timeout
+        if read_timeout is not None:
+            self._values["read_timeout"] = read_timeout
+
+    @builtins.property
+    def connection_attempts(self) -> typing.Optional[jsii.Number]:
+        '''The number of times that CloudFront attempts to connect to the origin;
+
+        valid values are 1, 2, or 3 attempts.
+
+        :default: 3
+        '''
+        result = self._values.get("connection_attempts")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def connection_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+        '''The number of seconds that CloudFront waits when trying to establish a connection to the origin.
+
+        Valid values are 1-10 seconds, inclusive.
+
+        :default: Duration.seconds(10)
+        '''
+        result = self._values.get("connection_timeout")
+        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+
+    @builtins.property
+    def custom_headers(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        '''A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
+
+        :default: {}
+        '''
+        result = self._values.get("custom_headers")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
+
+    @builtins.property
+    def origin_shield_region(self) -> typing.Optional[builtins.str]:
+        '''When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
+
+        :default: - origin shield not enabled
+
+        :see: https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html
+        '''
+        result = self._values.get("origin_shield_region")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def keepalive_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+        '''Specifies how long, in seconds, CloudFront persists its connection to the origin.
+
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
+
+        :default: Duration.seconds(5)
+        '''
+        result = self._values.get("keepalive_timeout")
+        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+
+    @builtins.property
+    def read_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+        '''Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
+
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
+
+        :default: Duration.seconds(30)
+        '''
+        result = self._values.get("read_timeout")
+        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "RestApiOriginProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.aws_cloudfront.IOrigin)
 class S3Origin(
     metaclass=jsii.JSIIMeta,
@@ -927,27 +1149,27 @@ class S3Origin(
         bucket: aws_cdk.aws_s3.IBucket,
         *,
         origin_access_identity: typing.Optional[aws_cdk.aws_cloudfront.IOriginAccessIdentity] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param bucket: -
         :param origin_access_identity: An optional Origin Access Identity of the origin identity cloudfront will use when calling your s3 bucket. Default: - An Origin Access Identity will be created.
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         props = S3OriginProps(
             origin_access_identity=origin_access_identity,
+            origin_path=origin_path,
             connection_attempts=connection_attempts,
             connection_timeout=connection_timeout,
             custom_headers=custom_headers,
-            origin_path=origin_path,
             origin_shield_region=origin_shield_region,
         )
 
@@ -977,8 +1199,8 @@ class S3Origin(
         "connection_attempts": "connectionAttempts",
         "connection_timeout": "connectionTimeout",
         "custom_headers": "customHeaders",
-        "origin_path": "originPath",
         "origin_shield_region": "originShieldRegion",
+        "origin_path": "originPath",
         "origin_access_identity": "originAccessIdentity",
     },
 )
@@ -989,8 +1211,8 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
         custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        origin_path: typing.Optional[builtins.str] = None,
         origin_shield_region: typing.Optional[builtins.str] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         origin_access_identity: typing.Optional[aws_cdk.aws_cloudfront.IOriginAccessIdentity] = None,
     ) -> None:
         '''Properties to use to customize an S3 Origin.
@@ -998,8 +1220,8 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
-        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
+        :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
         :param origin_access_identity: An optional Origin Access Identity of the origin identity cloudfront will use when calling your s3 bucket. Default: - An Origin Access Identity will be created.
 
         :exampleMetadata: infused
@@ -1022,10 +1244,10 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
             self._values["connection_timeout"] = connection_timeout
         if custom_headers is not None:
             self._values["custom_headers"] = custom_headers
-        if origin_path is not None:
-            self._values["origin_path"] = origin_path
         if origin_shield_region is not None:
             self._values["origin_shield_region"] = origin_shield_region
+        if origin_path is not None:
+            self._values["origin_path"] = origin_path
         if origin_access_identity is not None:
             self._values["origin_access_identity"] = origin_access_identity
 
@@ -1062,17 +1284,6 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
         result = self._values.get("custom_headers")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
-    @builtins.property
-    def origin_path(self) -> typing.Optional[builtins.str]:
-        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
-
-        Must begin, but not end, with '/' (e.g., '/production/images').
-
-        :default: '/'
-        '''
-        result = self._values.get("origin_path")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def origin_shield_region(self) -> typing.Optional[builtins.str]:
         '''When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
@@ -1084,6 +1295,17 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
         result = self._values.get("origin_shield_region")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def origin_path(self) -> typing.Optional[builtins.str]:
+        '''An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
+
+        Must begin, but not end, with '/' (e.g., '/production/images').
+
+        :default: '/'
+        '''
+        result = self._values.get("origin_path")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def origin_access_identity(
         self,
@@ -1114,6 +1336,8 @@ __all__ = [
     "LoadBalancerV2OriginProps",
     "OriginGroup",
     "OriginGroupProps",
+    "RestApiOrigin",
+    "RestApiOriginProps",
     "S3Origin",
     "S3OriginProps",
 ]
